==> nextcloud-11.0.2.tgz: nextcloud/apps/encryption/l10n/pt_PT.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Palavra-passe da chave de recuperação em falta",
    "Please repeat the recovery key password" : "Por favor, repita a palavra-passe da chave de recuperação",
    "Repeated recovery key password does not match the provided recovery key password" : "A confirmação da palavra-passe da chave de recuperação não corresponde",
    "Recovery key successfully enabled" : "A chave de recuperação foi ativada com sucesso",
    "Could not enable recovery key. Please check your recovery key password!" : "Não foi possível ativar a chave de recuperação. Por favor, verifique a sua palavra-passe da chave de recuperação!",
    "Recovery key successfully disabled" : "A chave de recuperação foi desativada com sucesso",
    "Could not disable recovery key. Please check your recovery key password!" : "Não foi possível desativar a chave de recuperação. Por favor, verifique a palavra-passe da chave de recuperação.",
    "Missing parameters" : "Parâmetros em falta",
    "Please provide the old recovery password" : "Por favor, indique a palavra-passe de recuperação antiga",
    "Please provide a new recovery password" : "Por favor, indique a nova palavra-passe de recuperação",
    "Please repeat the new recovery password" : "Por favor, repita a nova palavra-passe de recuperação",
    "Password successfully changed." : "Palavra-passe alterada com sucesso.",
    "Could not change the password. Maybe the old password was not correct." : "Não foi possível alterar a palavra-passe. Possivelmente a palavra-passe antiga não está correta.",
    "Recovery Key disabled" : "Chave de Recuperação desativada",
    "Recovery Key enabled" : "Chave de Recuperação ativada",
    "Could not enable the recovery key, please try again or contact your administrator" : "Não foi possível ativar a chave de recuperação, por favor, tente de novo ou contacte o seu administrador",
    "Could not update the private key password." : "Não foi possível atualizar a palavra-passe da chave privada.",
    "The old password was not correct, please try again." : "A palavra-passe antiga não estava correta, por favor, tente de novo.",
    "The current log-in password was not correct, please try again." : "A palavra-passe de iniciar a sessão atual não estava correta, por favor, tente de novo.",
    "Private key password successfully updated." : "A palavra-passe da chave privada foi atualizada com sucesso. ",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Precisa de migrar as suas chaves de encriptação da encriptação antiga (ownCloud <= 8.0) para a nova. Por favor, execute 'occ encryption:migrate' ou contacte o seu administrador",
    "Bad Signature" : "Má Assinatura",
    "Missing Signature" : "Assinatura em Falta",
    "one-time password for server-side-encryption" : "palavra-passe de utilização única para a encriptação do lado do servidor",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Não é possível desencriptar este ficheiro, provavelmente é um ficheiro partilhado. Por favor, peça ao proprietário do ficheiro para voltar a partilhar o ficheiro consigo.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Não é possível ler este ficheiro, provavelmente isto é um ficheiro compartilhado. Por favor, peça ao dono do ficheiro para voltar a partilhar o ficheiro consigo.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Olá,\n\no administrador ativou a encriptação do lado do servidor. Os teus ficheiros foram encriptados usando a palavra-passe '%s'.\n\nPor favor, faz login via browser, vai à secção 'Módulo de encriptação básica' nas tuas definições pessoais e atualiza a tua palavra-passe de encriptação ao introduzir esta palavra-passe no campo 'palavra-passe antiga' e também a tua palavra-passe atual.\n\n",
    "The share will expire on %s." : "Esta partilha irá expirar em %s.",
    "Cheers!" : "Parabéns!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Olá,<br><br>o administrador ativou a encriptação do lado do servidor. Os teus ficheiros foram encriptados usando a palavra-passe <strong>%s</strong>.<br><br>Por favor, faz login via browser, vai à secção 'Módulo de encriptação básica' nas tuas definições pessoais e atualiza a tua palavra-passe de encriptação ao introduzir esta palavra-passe no campo 'palavra-passe antiga' e também a tua palavra-passe atual.<br><br>",
    "Encrypt the home storage" : "Encriptar o armazenamento do início",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ativando esta opção todos os ficheiros armazenados no armazenamento principal serão encriptados, senão serão encriptados todos os ficheiros no armazenamento externo",
    "Enable recovery key" : "Ativar a chave de recuperação",
    "Disable recovery key" : "Desativar a chave de recuperação",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "A chave de recuperação é uma chave de encriptação extra que é utilizada para encriptar os ficheiros. Esta permite a recuperação dos ficheiros do utilizador se este esquecer a sua senha.",
    "Recovery key password" : "Palavra-passe da chave de recuperação",
    "Repeat recovery key password" : "Repetir a palavra-passe da chave de recuperação",
    "Change recovery key password:" : "Alterar a palavra-passe da chave de recuperação:",
    "Old recovery key password" : "Palavra-passe da chave de recuperação antiga",
    "New recovery key password" : "Nova palavra-passe da chave de recuperação",
    "Repeat new recovery key password" : "Repetir palavra-passe da chave de recuperação",
    "Change Password" : "Alterar Palavra-passe",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "A Aplicação de Encriptação está ativada, mas as suas chaves não inicializaram. Por favor, termine a sessão e inicie-a novamente",
    "Your private key password no longer matches your log-in password." : "A palavra-passe da sua chave privada já não coincide com a palavra-passe da sua sessão.",
    "Set your old private key password to your current log-in password:" : "Defina a sua palavra-passe antiga da chave privada para a sua palavra-passe atual da sessão:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Se não se lembra da palavra-passe antiga pode pedir ao seu administrador para recuperar os seus ficheiros. ",
    "Old log-in password" : "Palavra-passe antiga da sessão",
    "Current log-in password" : "Palavra-passe atual da sessão",
    "Update Private Key Password" : "Atualizar Palavra-passe da Chave Privada ",
    "Enable password recovery:" : "Ativar a recuperação da palavra-passe:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ao ativar esta opção, irá fazer com que volte a obter o acesso aos seus ficheiros encriptados, se perder a palavra-passe",
    "Enabled" : "Ativada",
    "Disabled" : "Desativada"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/encryption/l10n/pt_PT.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Palavra-passe da chave de recuperação em falta",
    "Please repeat the recovery key password" : "Por favor, repita a palavra-passe da chave de recuperação",
    "Repeated recovery key password does not match the provided recovery key password" : "A confirmação da palavra-passe da chave de recuperação não corresponde",
    "Recovery key successfully enabled" : "A chave de recuperação foi ativada com sucesso",
    "Could not enable recovery key. Please check your recovery key password!" : "Não foi possível ativar a chave de recuperação. Por favor, verifique a sua palavra-passe da chave de recuperação!",
    "Recovery key successfully disabled" : "A chave de recuperação foi desativada com sucesso",
    "Could not disable recovery key. Please check your recovery key password!" : "Não foi possível desativar a chave de recuperação. Por favor, verifique a palavra-passe da chave de recuperação.",
    "Missing parameters" : "Parâmetros em falta",
    "Please provide the old recovery password" : "Por favor, indique a palavra-passe de recuperação antiga",
    "Please provide a new recovery password" : "Por favor, indique a nova palavra-passe de recuperação",
    "Please repeat the new recovery password" : "Por favor, repita a nova palavra-passe de recuperação",
    "Password successfully changed." : "Palavra-passe alterada com sucesso.",
    "Could not change the password. Maybe the old password was not correct." : "Não foi possível alterar a palavra-passe. Possivelmente a palavra-passe antiga não está correta.",
    "Recovery Key disabled" : "Chave de Recuperação desativada",
    "Recovery Key enabled" : "Chave de Recuperação ativada",
    "Could not enable the recovery key, please try again or contact your administrator" : "Não foi possível ativar a chave de recuperação, por favor, tente de novo ou contacte o seu administrador",
    "Could not update the private key password." : "Não foi possível atualizar a palavra-passe da chave privada.",
    "The old password was not correct, please try again." : "A palavra-passe antiga não estava correta, por favor, tente de novo.",
    "The current log-in password was not correct, please try again." : "A palavra-passe de iniciar a sessão atual não estava correta, por favor, tente de novo.",
    "Private key password successfully updated." : "A palavra-passe da chave privada foi atualizada com sucesso. ",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Chave privada inválida para a aplicação de cifra. Por favor actualize a sua chave privada nas definições pessoais para recuperar acesso aos seus ficheiros cifrados.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplicação de cifra está activa, mas as suas chaves não estão inicializaras. Por favor, faça logout e autentique-se novamente.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Por favor active cifragem no servidor nas definições de administrador para usar o módulo de cifra.",
    "Encryption app is enabled and ready" : "Aplicação de cifra activa e pronta a usar",
    "Bad Signature" : "Má Assinatura",
    "Missing Signature" : "Assinatura em Falta",
    "one-time password for server-side-encryption" : "palavra-passe de utilização única para a encriptação do lado do servidor",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Não é possível desencriptar este ficheiro, provavelmente é um ficheiro partilhado. Por favor, peça ao proprietário do ficheiro para voltar a partilhar o ficheiro consigo.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Não é possível ler este ficheiro, provavelmente isto é um ficheiro compartilhado. Por favor, peça ao dono do ficheiro para voltar a partilhar o ficheiro consigo.",
    "Default encryption module" : "Módulo de cifra padrão",
    "Default encryption module for server-side encryption" : "Módulo de encriptação predefinido para encriptação do lado do servidor",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Olá,\n\no administrador ativou a encriptação do lado do servidor. Os teus ficheiros foram encriptados usando a palavra-passe '%s'.\n\nPor favor, faz login via browser, vai à secção 'Módulo de encriptação básica' nas tuas definições pessoais e atualiza a tua palavra-passe de encriptação ao introduzir esta palavra-passe no campo 'palavra-passe antiga' e também a tua palavra-passe atual.\n\n",
    "The share will expire on %s." : "Esta partilha irá expirar em %s.",
    "Cheers!" : "Parabéns!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Olá,<br><br>o administrador ativou a encriptação do lado do servidor. Os teus ficheiros foram encriptados usando a palavra-passe <strong>%s</strong>.<br><br>Por favor, faz login via browser, vai à secção 'Módulo de encriptação básica' nas tuas definições pessoais e atualiza a tua palavra-passe de encriptação ao introduzir esta palavra-passe no campo 'palavra-passe antiga' e também a tua palavra-passe atual.<br><br>",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplicação de cifra está activa, mas as suas chaves não estão inicializaras. Por favor, faça logout e autentique-se novamente.",
    "Encrypt the home storage" : "Encriptar o armazenamento do início",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Ativando esta opção todos os ficheiros armazenados no armazenamento principal serão encriptados, senão serão encriptados todos os ficheiros no armazenamento externo",
    "Enable recovery key" : "Ativar a chave de recuperação",
    "Disable recovery key" : "Desativar a chave de recuperação",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "A chave de recuperação é uma chave de encriptação extra que é utilizada para encriptar os ficheiros. Esta permite a recuperação dos ficheiros do utilizador se este esquecer a sua senha.",
    "Recovery key password" : "Palavra-passe da chave de recuperação",
    "Repeat recovery key password" : "Repetir a palavra-passe da chave de recuperação",
    "Change recovery key password:" : "Alterar a palavra-passe da chave de recuperação:",
    "Old recovery key password" : "Palavra-passe da chave de recuperação antiga",
    "New recovery key password" : "Nova palavra-passe da chave de recuperação",
    "Repeat new recovery key password" : "Repetir palavra-passe da chave de recuperação",
    "Change Password" : "Alterar Palavra-passe",
    "Basic encryption module" : "Módulo de cifra básica",
    "Your private key password no longer matches your log-in password." : "A palavra-passe da sua chave privada já não coincide com a palavra-passe da sua sessão.",
    "Set your old private key password to your current log-in password:" : "Defina a sua palavra-passe antiga da chave privada para a sua palavra-passe atual da sessão:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Se não se lembra da palavra-passe antiga pode pedir ao seu administrador para recuperar os seus ficheiros. ",
    "Old log-in password" : "Palavra-passe antiga da sessão",
    "Current log-in password" : "Palavra-passe atual da sessão",
    "Update Private Key Password" : "Atualizar Palavra-passe da Chave Privada ",
    "Enable password recovery:" : "Ativar a recuperação da palavra-passe:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Ao ativar esta opção, irá fazer com que volte a obter o acesso aos seus ficheiros encriptados, se perder a palavra-passe",
    "Enabled" : "Ativada",
    "Disabled" : "Desativada",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Precisa de migrar as suas chaves de encriptação da encriptação antiga (ownCloud <= 8.0) para a nova. Por favor, execute 'occ encryption:migrate' ou contacte o seu administrador"
},
"nplurals=2; plural=(n != 1);");
